searchData={"items":[{"type":"module","title":"LiveFlip","doc":"`LiveFlip` is a component for `Phoenix.LiveView` that allows the user to seamlessly add FLIP animations to their elements on the page.","ref":"LiveFlip.html"},{"type":"function","title":"LiveFlip.flip_wrap/1","doc":"Wraps an element with a FLIP animation.\nThe element can be subsequently changed by changing its styling.\nAny change that has to do with positioning, scale, rotation, or opacity\nwill be automatically animated through the FLIP technique.\n\nFLIP stands for First, Last, Invert, Play. It is an animation technique coined by\nPaul Lewis in his article [FLIP Your Animations](https://aerotwist.com/blog/flip-your-animations/),\nwhich describes the technique in detail. The technique has subsequently been added to\nmany major libraries, as it adds the capability to seamlessly move elements around on a page.","ref":"LiveFlip.html#flip_wrap/1"},{"type":"function","title":"Attributes - LiveFlip.flip_wrap/1","doc":"* `id` (`:string`) (required) - The DOM identifier of the flip container tag.\n* `duration` (`:integer`) - The duration that the animation will last. Defaults to `300`.\n* `easing` (`:string`) - The easing function to pass to the Web Animation API. Defaults to `\"ease-in-out\"`.\n* `fill` (`:string`) - The fill function to pass to the Web Animation API. Defaults to `\"both\"`.\n* `debug` (`:boolean`) - Add debug logs to the frontend so that you can debug the animations. Defaults to `false`.\n* Global attributes are accepted. Additional HTML attributes to add to the flip container tag.","ref":"LiveFlip.html#flip_wrap/1-attributes"},{"type":"function","title":"Slots - LiveFlip.flip_wrap/1","doc":"* `inner_block` (required) - The content rendered inside of the flip container tag.","ref":"LiveFlip.html#flip_wrap/1-slots"},{"type":"function","title":"Examples - LiveFlip.flip_wrap/1","doc":"Simply render your inner content within this component and move it around the page by adjusting\nits classes. The element will automatically animate its movement:\n\n```heex\n<.flip_wrap id=\"my-red-square\">\n   \n   \n</.flip_wrap>\n```","ref":"LiveFlip.html#flip_wrap/1-examples"},{"type":"extras","title":"README","doc":"# LiveFlip\n\n[![Hex.pm Version](https://img.shields.io/hexpm/v/live_flip.svg)](https://hex.pm/packages/live_flip) [![Documentation](https://img.shields.io/badge/docs-latest-blue.svg)](https://hexdocs.pm/live_flip/)\n\nA component and hook for FLIP animations of elements within LiveView.","ref":"readme.html"},{"type":"extras","title":"How To Use - README","doc":"A demo project is provided here in the demo folder, it is a simple demo app to display the capability that the component provides. You can visit [live-flip.fly.dev](https://live-flip.fly.dev) to see it in action. The animations are fully automated by the wrapper, and the class changes are fully driven by the server.\n\nThe easiest way to start is to install (see the below Installation section), and add the Flip hook to your hooks in your app's `app.js` file. Once you have that, you can wrap any element in the `flip_wrap` component and receive all the animations for free!\n\nIn your app.js, or wherever you define your hooks, simply import the following:\n\n```javascript\nimport Flip from \"../../deps/live_flip/assets/js/hooks\"\n```\n\nOr, if you are in an umbrella project:\n\n```javascript\nimport Flip from \"../../../../deps/live_flip/assets/js/hooks\"\n```\n\nAnd then add the hook to your Hooks object:\n\n```javascript\nlet liveSocket = new LiveSocket(\"/live\", Socket, {\n  hooks: { Flip },\n})\n```","ref":"readme.html#how-to-use"},{"type":"extras","title":"Caveats - README","doc":"As of now (version 0.1.0), animations and FLIPs are implemented for the following:\n- Position changes\n- Width changes\n- Height changes\n\nHowever, since the hook utilizes the Web Animations API and transforms, it is unable to handle if the element has transforms applied on it (yet). This is something that I want to tackle in following releases, as I get a better handle of how to compose transforms that are already on an element, with incoming transforms during an update and the transforms necessary for the FLIP to work.\n\nIn addition to this caveat - the UI is non-blocking right now - this means that animations may be running as your element changes classes. I'm not currently using LiveView's `this.js` ViewHook functionality to trigger transitions - mainly because I want to target the Web Animations API and keep this hook very generic (i.e. not targeting Tailwind and not class-based). My understanding of the `this.js.transition` function is that it works by adding classes and transitioning these classes off, meaning that I would need to dynamically calculate the TailwindCSS classes necessary for the FLIP thus tying this very much to Tailwind exclusively. Unfortunately, this also means I can't cause the UI to lock or be blocked - there have been many discussions about this in the past, both on the forum and on the Slack. I'm hoping that this (as a nice use case for it) will open up the discussion again.","ref":"readme.html#caveats"},{"type":"extras","title":"Installation - README","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `live_flip` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:live_flip, \"~> 0.1.0\"}\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#installation"},{"type":"extras","title":"Contributing - README","doc":"Feel free to fork and make PRs! I'm definitely happy to have eyes on this and to get feedback so we can take care of edge cases.","ref":"readme.html#contributing"}],"content_type":"text/markdown","proglang":"elixir","producer":{"name":"ex_doc","version":"0.36.1"}}